{% extends "epic/base_layout.html" %}
{% load crispy_forms_tags %}
{% load staticfiles %}

{% block extrahead %}
{{ block.super }}
{{ part_form.media }}
{{ vendor_form.media }}
<script src="{% static "epic/js/editing.js" %}"></script>
<script src="{% static "epic/js/substitute-editor.js" %}"></script>
{% endblock extrahead %}

{% block content %}
{{ block.super }}

<form method="POST">
<div class="form-horizontal">
{% crispy part_form %}
</div>
{% crispy vendor_form %}

<div class="form-actions">
  <input type="submit" name="save" value="Save" class="btn btn-primary">
  <input type="submit" name="cancel" value="Cancel"
	 class="btn btn-default">
</div>
</form>

<br>

{% endblock content %}
